/* NiceXSL lexer

 Copyright (c) 2002 The Regents of the University of California.
 All rights reserved.
 Permission is hereby granted, without written agreement and without
 license or royalty fees, to use, copy, modify, and distribute this
 software and its documentation for any purpose, provided that the above
 copyright notice and the following two paragraphs appear in all copies
 of this software.

 IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF
 THE UNIVERSITY OF CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE
 PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 CALIFORNIA HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
 ENHANCEMENTS, OR MODIFICATIONS.

                                        PT_COPYRIGHT_VERSION_2
                                        COPYRIGHTENDKEY

@ProposedRating Red (Ed.Willink@uk.thalesgroup.com)
@AcceptedRating Red

Created : August 2002

Version 1.2: 27-Aug-2002
1.2.1 3-Sep-2002 Fix bugs detected by JFlex, upper case class names
    Track columns, activate Unicode
  EDW 17-Sep-2002 Fix idiv tokenisation
Version 1.2.2: 18-Sep-2002

*/
package nicexsl;

import java_cup.runtime.Symbol;
import java.lang.Integer;
import java.lang.String;

/**
Lexing class for NiceXSL.
<p>
This JLex lexer supports the CUP parser via the java_cup.runtime.Scanner interface.
<p>
It uses a single state for all XML, XSL and XPath context, save for a brief excursion into
the XML_DT or XML_PI state in response to a setDocumentType() or setProcessingInstruction()
request to read the body of an XML processing instruction.
<p>
The lexer supports the full Unicode character set but takes a few minutes
to build with JFlex-1.4_pre1. In order to build with JFlex-1.3.5 the greater
than 8 bit terms must be commented out.

@author Ed Willink
@version $Id$
@see nicexsl.Main nicexsl.Parser
*/
%%

%public
%class Lexer
%cupsym Terminal
%cup

%state XML_DT,XML_PI
%{
    public void setDocumentType() { yybegin(XML_DT); }
    public void setProcessingInstruction() { yybegin(XML_PI); }

    public final String kwAnalyzeString = new String("analyze-string");
    public final String kwAncestor = new String("ancestor");
    public final String kwAncestorOrSelf = new String("ancestor-or-self");
    public final String kwAnd = new String("and");
    public final String kwApplyImports = new String("apply-imports");
    public final String kwApplyTemplates = new String("apply-templates");
    public final String kwAs = new String("as");
    public final String kwAtomic = new String("atomic");
    public final String kwAttribute = new String("attribute");
    public final String kwAttributeSet = new String("attribute-set");
    public final String kwCall = new String("call");
    public final String kwCast = new String("cast");
    public final String kwChild = new String("child");
    public final String kwChoose = new String("choose");
    public final String kwComment = new String("comment");
    public final String kwCopy = new String("copy");
    public final String kwCopyOf = new String("copy-of");
    public final String kwDecimalFormat = new String("decimal-format");
    public final String kwDescendant = new String("descendant");
    public final String kwDescendantOrSelf = new String("descendant-or-self");
    public final String kwDiv = new String("div");
    public final String kwDocument = new String("document");
    public final String kwElement = new String("element");
    public final String kwElse = new String("else");
    public final String kwElseIf = new String("elseif");
    public final String kwEmpty = new String("empty");
    public final String kwEq = new String("eq");
    public final String kwEvery = new String("every");
    public final String kwExcept = new String("except");
    public final String kwFallback = new String("fallback");
    public final String kwFollowing = new String("following");
    public final String kwFollowingSibling = new String("following-sibling");
    public final String kwFor = new String("for");
    public final String kwForEach = new String("for-each");
    public final String kwForEachGroup = new String("for-each-group");
    public final String kwFunction = new String("function");
    public final String kwGe = new String("ge");
    public final String kwGt = new String("gt");
    public final String kwIdiv = new String("idiv");
    public final String kwIf = new String("if");
    public final String kwImport = new String("import");
    public final String kwImportSchema = new String("import-schema");
    public final String kwIn = new String("in");
    public final String kwInclude = new String("include");
    public final String kwInstance = new String("instance");
    public final String kwIntersect = new String("intersect");
    public final String kwIs = new String("is");
    public final String kwIsNot = new String("isnot");
    public final String kwItem = new String("item");
    public final String kwKey = new String("key");
    public final String kwLe = new String("le");
    public final String kwLt = new String("lt");
    public final String kwMatch = new String("match");
    public final String kwMatchingSubstring = new String("matching-substring");
    public final String kwMessage = new String("message");
    public final String kwMod = new String("mod");
    public final String kwNamespace = new String("namespace");
    public final String kwNamespaceAlias = new String("namespace-alias");
    public final String kwNe = new String("ne");
    public final String kwNode = new String("node");
    public final String kwNonMatchingSubstring = new String("non-matching-substring");
    public final String kwNumber = new String("number");
    public final String kwOf = new String("of");
    public final String kwOr = new String("or");
    public final String kwOtherwise = new String("otherwise");
    public final String kwOutput = new String("output");
    public final String kwParent = new String("parent");
    public final String kwPreceding = new String("preceding");
    public final String kwPrecedingSibling = new String("preceding-sibling");
    public final String kwPreserveSpace = new String("preserve-space");
    public final String kwPrincipalResultDocument = new String("principal-result-document");
    public final String kwProcessingInstruction = new String("processing-instruction");
    public final String kwResult = new String("result");
    public final String kwResultDocument = new String("result-document");
    public final String kwReturn = new String("return");
    public final String kwSatisfies = new String("satisfies");
    public final String kwSelf = new String("self");
    public final String kwSome = new String("some");
    public final String kwSort = new String("sort");
    public final String kwSortKey = new String("sort-key");
    public final String kwStripSpace = new String("strip-space");
    public final String kwStylesheet = new String("stylesheet");
    public final String kwText = new String("text");
    public final String kwThen = new String("then");
    public final String kwTo = new String("to");
    public final String kwTreat = new String("treat");
    public final String kwType = new String("type");
    public final String kwUnion = new String("union");
    public final String kwUnordered = new String("unordered");
    public final String kwUntyped = new String("untyped");
    public final String kwValidate = new String("validate");
    public final String kwValue = new String("value");
    public final String kwValueOf = new String("value-of");
    public final String kwVariable = new String("variable");
    public final String kwWhen = new String("when");
    public final String kwXml = new String("xml");

    public final String opAt = new String("@");
    public final String opColon = new String(":");
    public final String opColonColon = new String("::");
    public final String opColonEquals = new String(":=");
    public final String opComma = new String(",");
    public final String opDollar = new String("$");
    public final String opDot = new String(".");
    public final String opDotDot = new String("..");
    public final String opEquals = new String("=");
    public final String opGt = new String(">");
    public final String opGtEquals = new String(">=");
    public final String opLBrace = new String("{");
    public final String opLBrack = new String("[");
    public final String opLPar = new String("(");
    public final String opLt = new String("<");
    public final String opLtEquals = new String("<=");
    public final String opMinus = new String("-");
    public final String opNotEquals = new String("!=");
    public final String opPling = new String("!");
    public final String opPlus = new String("+");
    public final String opQmark = new String("?");
    public final String opRBrace = new String("}");
    public final String opRBrack = new String("]");
    public final String opRPar = new String(")");
    public final String opSemi = new String(";");
    public final String opSlash = new String("/");
    public final String opSlashSlash = new String("//");
    public final String opStar = new String("*");
    public final String opVBar = new String("|");

    //
    //	Convert incoming & character references to literal characters for internal use.
    //
    public static String decode(String t) {
        int iMax = t.length();
        StringBuffer result = new StringBuffer(iMax);
        for (int i = 0; i < iMax; ) {
            char c = t.charAt(i);
            int semiIndex = 0;
            if (c != '&') {
                result.append(c);
                i++;
            }
            else if ((i + 4 <= iMax) && t.substring(i, i + 4).equals("&gt;")) {
                result.append('>');
                i += 4;
            }
            else if ((i + 4 <= iMax) && t.substring(i, i + 4).equals("&lt;")) {
                result.append('<');
                i += 4;
            }
            else if ((i + 5 <= iMax) && t.substring(i, i + 5).equals("&amp;")) {
                result.append('&');
                i += 5;
            }
            else if ((i + 6 <= iMax) && t.substring(i, i + 6).equals("&quot;")) {
                result.append('"');
                i += 6;
            }
            else if ((i + 3 <= iMax) && t.substring(i, i + 3).equals("&#x") && ((semiIndex = t.indexOf(';', i+3)) > 0)) {
                String n = t.substring(i+3 , semiIndex);
                result.append((char)Integer.parseInt(n, 16));
                i = semiIndex+1;
            }
            else if ((i + 2 <= iMax) && t.substring(i, i + 2).equals("&#") && ((semiIndex = t.indexOf(';', i+2)) > 0)) {
                String n = t.substring(i+2 , semiIndex);
                result.append((char)Integer.parseInt(n, 10));
                i = semiIndex+1;
            }
            else {
                result.append(c);
                i++;
            }
        }
        return result.toString();
    }
%}

%line
%column
%unicode

SingleLineComment = ("--"[^\n]*\n)
MultiLineComment = ("<!--"([^-]|"-"[^-]|"--"[^>])*"-->")
ExprComment = ("{--"([^-]|"-"[^-]|"--"[^}])*"--}")
DocumentType=([^>]*)
ProcessingInstruction=(([^?]|"?"[^>])*)
StringLiteral = ("'"[^']*"'")|("\""[^\"]*"\"")

BaseChar = [\u0041-\u005A]
        | [\u0061-\u007A] | [\u00C0-\u00D6]
        | [\u00D8-\u00F6] | [\u00F8-\u00FF]
        | [\u0100-\u0131] | [\u0134-\u013E]
        | [\u0141-\u0148] | [\u014A-\u017E]
        | [\u0180-\u01C3] | [\u01CD-\u01F0]
        | [\u01F4-\u01F5] | [\u01FA-\u0217]
        | [\u0250-\u02A8] | [\u02BB-\u02C1]
        | \u0386 | [\u0388-\u038A] | \u038C
        | [\u038E-\u03A1] | [\u03A3-\u03CE]
        | [\u03D0-\u03D6] | \u03DA | \u03DC
        | \u03DE | \u03E0 | [\u03E2-\u03F3]
        | [\u0401-\u040C] | [\u040E-\u044F]
        | [\u0451-\u045C] | [\u045E-\u0481]
        | [\u0490-\u04C4] | [\u04C7-\u04C8]
        | [\u04CB-\u04CC] | [\u04D0-\u04EB]
        | [\u04EE-\u04F5] | [\u04F8-\u04F9]
        | [\u0531-\u0556] | \u0559
        | [\u0561-\u0586] | [\u05D0-\u05EA]
        | [\u05F0-\u05F2] | [\u0621-\u063A]
        | [\u0641-\u064A] | [\u0671-\u06B7]
        | [\u06BA-\u06BE] | [\u06C0-\u06CE]
        | [\u06D0-\u06D3] | \u06D5
        | [\u06E5-\u06E6] | [\u0905-\u0939]
        | \u093D | [\u0958-\u0961]
        | [\u0985-\u098C] | [\u098F-\u0990]
        | [\u0993-\u09A8] | [\u09AA-\u09B0]
        | \u09B2 | [\u09B6-\u09B9]
        | [\u09DC-\u09DD] | [\u09DF-\u09E1]
        | [\u09F0-\u09F1] | [\u0A05-\u0A0A]
        | [\u0A0F-\u0A10] | [\u0A13-\u0A28]
        | [\u0A2A-\u0A30] | [\u0A32-\u0A33]
        | [\u0A35-\u0A36] | [\u0A38-\u0A39]
        | [\u0A59-\u0A5C] | \u0A5E
        | [\u0A72-\u0A74] | [\u0A85-\u0A8B]
        | \u0A8D | [\u0A8F-\u0A91]
        | [\u0A93-\u0AA8] | [\u0AAA-\u0AB0]
        | [\u0AB2-\u0AB3] | [\u0AB5-\u0AB9]
        | \u0ABD | \u0AE0 | [\u0B05-\u0B0C]
        | [\u0B0F-\u0B10] | [\u0B13-\u0B28]
        | [\u0B2A-\u0B30] | [\u0B32-\u0B33]
        | [\u0B36-\u0B39] | \u0B3D
        | [\u0B5C-\u0B5D] | [\u0B5F-\u0B61]
        | [\u0B85-\u0B8A] | [\u0B8E-\u0B90]
        | [\u0B92-\u0B95] | [\u0B99-\u0B9A]
        | \u0B9C | [\u0B9E-\u0B9F]
        | [\u0BA3-\u0BA4] | [\u0BA8-\u0BAA]
        | [\u0BAE-\u0BB5] | [\u0BB7-\u0BB9]
        | [\u0C05-\u0C0C] | [\u0C0E-\u0C10]
        | [\u0C12-\u0C28] | [\u0C2A-\u0C33]
        | [\u0C35-\u0C39] | [\u0C60-\u0C61]
        | [\u0C85-\u0C8C] | [\u0C8E-\u0C90]
        | [\u0C92-\u0CA8] | [\u0CAA-\u0CB3]
        | [\u0CB5-\u0CB9] | \u0CDE
        | [\u0CE0-\u0CE1] | [\u0D05-\u0D0C]
        | [\u0D0E-\u0D10] | [\u0D12-\u0D28]
        | [\u0D2A-\u0D39] | [\u0D60-\u0D61]
        | [\u0E01-\u0E2E] | \u0E30
        | [\u0E32-\u0E33] | [\u0E40-\u0E45]
        | [\u0E81-\u0E82] | \u0E84
        | [\u0E87-\u0E88] | \u0E8A | \u0E8D
        | [\u0E94-\u0E97] | [\u0E99-\u0E9F]
        | [\u0EA1-\u0EA3] | \u0EA5 | \u0EA7
        | [\u0EAA-\u0EAB] | [\u0EAD-\u0EAE]
        | \u0EB0 | [\u0EB2-\u0EB3] | \u0EBD
        | [\u0EC0-\u0EC4] | [\u0F40-\u0F47]
        | [\u0F49-\u0F69] | [\u10A0-\u10C5]
        | [\u10D0-\u10F6] | \u1100
        | [\u1102-\u1103] | [\u1105-\u1107]
        | \u1109 | [\u110B-\u110C]
        | [\u110E-\u1112] | \u113C | \u113E
        | \u1140 | \u114C | \u114E | \u1150
        | [\u1154-\u1155] | \u1159
        | [\u115F-\u1161] | \u1163 | \u1165
        | \u1167 | \u1169 | [\u116D-\u116E]
        | [\u1172-\u1173] | \u1175 | \u119E
        | \u11A8 | \u11AB | [\u11AE-\u11AF]
        | [\u11B7-\u11B8] | \u11BA
        | [\u11BC-\u11C2] | \u11EB | \u11F0
        | \u11F9 | [\u1E00-\u1E9B]
        | [\u1EA0-\u1EF9] | [\u1F00-\u1F15]
        | [\u1F18-\u1F1D] | [\u1F20-\u1F45]
        | [\u1F48-\u1F4D] | [\u1F50-\u1F57]
        | \u1F59 | \u1F5B | \u1F5D
        | [\u1F5F-\u1F7D] | [\u1F80-\u1FB4]
        | [\u1FB6-\u1FBC] | \u1FBE
        | [\u1FC2-\u1FC4] | [\u1FC6-\u1FCC]
        | [\u1FD0-\u1FD3] | [\u1FD6-\u1FDB]
        | [\u1FE0-\u1FEC] | [\u1FF2-\u1FF4]
        | [\u1FF6-\u1FFC] | \u2126
        | [\u212A-\u212B] | \u212E
        | [\u2180-\u2182] | [\u3041-\u3094]
        | [\u30A1-\u30FA] | [\u3105-\u312C]
        | [\uAC00-\uD7A3]

Ideographic = [\u4E00-\u9FA5] | \u3007
        | [\u3021-\u3029] 

CombiningChar =  [\u0300-\u0345]
        | [\u0360-\u0361] | [\u0483-\u0486]
        | [\u0591-\u05A1] | [\u05A3-\u05B9]
        | [\u05BB-\u05BD] | \u05BF
        | [\u05C1-\u05C2] | \u05C4
        | [\u064B-\u0652] | \u0670
        | [\u06D6-\u06DC] | [\u06DD-\u06DF]
        | [\u06E0-\u06E4] | [\u06E7-\u06E8]
        | [\u06EA-\u06ED] | [\u0901-\u0903]
        | \u093C | [\u093E-\u094C] | \u094D
        | [\u0951-\u0954] | [\u0962-\u0963]
        | [\u0981-\u0983] | \u09BC | \u09BE
        | \u09BF | [\u09C0-\u09C4]
        | [\u09C7-\u09C8] | [\u09CB-\u09CD]
        | \u09D7 | [\u09E2-\u09E3] | \u0A02
        | \u0A3C | \u0A3E | \u0A3F
        | [\u0A40-\u0A42] | [\u0A47-\u0A48]
        | [\u0A4B-\u0A4D] | [\u0A70-\u0A71]
        | [\u0A81-\u0A83] | \u0ABC
        | [\u0ABE-\u0AC5] | [\u0AC7-\u0AC9]
        | [\u0ACB-\u0ACD] | [\u0B01-\u0B03]
        | \u0B3C | [\u0B3E-\u0B43]
        | [\u0B47-\u0B48] | [\u0B4B-\u0B4D]
        | [\u0B56-\u0B57] | [\u0B82-\u0B83]
        | [\u0BBE-\u0BC2] | [\u0BC6-\u0BC8]
        | [\u0BCA-\u0BCD] | \u0BD7
        | [\u0C01-\u0C03] | [\u0C3E-\u0C44]
        | [\u0C46-\u0C48] | [\u0C4A-\u0C4D]
        | [\u0C55-\u0C56] | [\u0C82-\u0C83]
        | [\u0CBE-\u0CC4] | [\u0CC6-\u0CC8]
        | [\u0CCA-\u0CCD] | [\u0CD5-\u0CD6]
        | [\u0D02-\u0D03] | [\u0D3E-\u0D43]
        | [\u0D46-\u0D48] | [\u0D4A-\u0D4D]
        | \u0D57 | \u0E31 | [\u0E34-\u0E3A]
        | [\u0E47-\u0E4E] | \u0EB1
        | [\u0EB4-\u0EB9] | [\u0EBB-\u0EBC]
        | [\u0EC8-\u0ECD] | [\u0F18-\u0F19]
        | \u0F35 | \u0F37 | \u0F39 | \u0F3E
        | \u0F3F | [\u0F71-\u0F84]
        | [\u0F86-\u0F8B] | [\u0F90-\u0F95]
        | \u0F97 | [\u0F99-\u0FAD]
        | [\u0FB1-\u0FB7] | \u0FB9
        | [\u20D0-\u20DC] | \u20E1
        | [\u302A-\u302F] | \u3099 | \u309A

Digit = [\u0030-\u0039]
        | [\u0660-\u0669] | [\u06F0-\u06F9]
        | [\u0966-\u096F] | [\u09E6-\u09EF]
        | [\u0A66-\u0A6F] | [\u0AE6-\u0AEF]
        | [\u0B66-\u0B6F] | [\u0BE7-\u0BEF]
        | [\u0C66-\u0C6F] | [\u0CE6-\u0CEF]
        | [\u0D66-\u0D6F] | [\u0E50-\u0E59]
        | [\u0ED0-\u0ED9] | [\u0F20-\u0F29]

Extender = \u00B7 | \u02D0
        | \u02D1 | \u0387 | \u0640 | \u0E46
        | \u0EC6 | \u3005 | [\u3031-\u3035]
        | [\u309D-\u309E] | [\u30FC-\u30FE]

Letter = {BaseChar} | {Ideographic} 

Digits=([0-9]+)
IntegerLiteral={Digits}
DecimalLiteral=(("."{Digits})|({Digits}"."[0-9]*))
DoubleLiteral=(("."{Digits})|({Digits}("."[0-9]*)?)[eE][+-]?{Digits})

Nmstart=({Letter}|"_")
Nmchar=({Letter}|{CombiningChar}|{Extender}|{Digit}|"."|"-"|"_")
NCName=({Nmstart}({Nmchar})*)
%%
<XML_DT>{DocumentType} { yybegin(YYINITIAL); return new Symbol(Terminal.DocumentType, yyline+1, yycolumn+1, decode(yytext())); }
<XML_PI>{ProcessingInstruction} { yybegin(YYINITIAL); return new Symbol(Terminal.ProcessingInstruction, yyline+1, yycolumn+1, decode(yytext())); }

"analyze-string" { return new Symbol(Terminal.ANALYZE_STRING, yyline+1, yycolumn+1, kwAnalyzeString); }
"ancestor" { return new Symbol(Terminal.ANCESTOR, yyline+1, yycolumn+1, kwAncestor); }
"ancestor-or-self" { return new Symbol(Terminal.ANCESTOR_OR_SELF, yyline+1, yycolumn+1, kwAncestorOrSelf); }
"and" { return new Symbol(Terminal.AND, yyline+1, yycolumn+1, kwAnd); }
"apply-imports" { return new Symbol(Terminal.APPLY_IMPORTS, yyline+1, yycolumn+1, kwApplyImports); }
"apply-templates" { return new Symbol(Terminal.APPLY_TEMPLATES, yyline+1, yycolumn+1, kwApplyTemplates); }
"as" { return new Symbol(Terminal.AS, yyline+1, yycolumn+1, kwAs); }
"atomic" { return new Symbol(Terminal.ATOMIC, yyline+1, yycolumn+1, kwAtomic); }
"attribute" { return new Symbol(Terminal.ATTRIBUTE, yyline+1, yycolumn+1, kwAttribute); }
"attribute-set" { return new Symbol(Terminal.ATTRIBUTE_SET, yyline+1, yycolumn+1, kwAttributeSet); }
"call" { return new Symbol(Terminal.CALL, yyline+1, yycolumn+1, kwCall); }
"cast" { return new Symbol(Terminal.CAST, yyline+1, yycolumn+1, kwCast); }
"child" { return new Symbol(Terminal.CHILD, yyline+1, yycolumn+1, kwChild); }
"choose" { return new Symbol(Terminal.CHOOSE, yyline+1, yycolumn+1, kwChoose); }
"comment" { return new Symbol(Terminal.COMMENT, yyline+1, yycolumn+1, kwComment); }
"copy" { return new Symbol(Terminal.COPY, yyline+1, yycolumn+1, kwCopy); }
"copy-of" { return new Symbol(Terminal.COPY_OF, yyline+1, yycolumn+1, kwCopyOf); }
"decimal-format" { return new Symbol(Terminal.DECIMAL_FORMAT, yyline+1, yycolumn+1, kwDecimalFormat); }
"descendant" { return new Symbol(Terminal.DESCENDANT, yyline+1, yycolumn+1, kwDescendant); }
"descendant-or-self" { return new Symbol(Terminal.DESCENDANT_OR_SELF, yyline+1, yycolumn+1, kwDescendantOrSelf); }
"div" { return new Symbol(Terminal.DIV, yyline+1, yycolumn+1, kwDiv); }
"document" { return new Symbol(Terminal.DOCUMENT, yyline+1, yycolumn+1, kwDocument); }
"element" { return new Symbol(Terminal.ELEMENT, yyline+1, yycolumn+1, kwElement); }
"else" { return new Symbol(Terminal.ELSE, yyline+1, yycolumn+1, kwElse); }
"elseif" { return new Symbol(Terminal.ELSEIF, yyline+1, yycolumn+1, kwElseIf); }
"empty" { return new Symbol(Terminal.EMPTY, yyline+1, yycolumn+1, kwEmpty); }
"eq" { return new Symbol(Terminal.FORTRAN_EQ, yyline+1, yycolumn+1, kwEq); }
"every" { return new Symbol(Terminal.EVERY, yyline+1, yycolumn+1, kwEvery); }
"except" { return new Symbol(Terminal.EXCEPT, yyline+1, yycolumn+1, kwExcept); }
"fallback" { return new Symbol(Terminal.FALLBACK, yyline+1, yycolumn+1, kwFallback); }
"following" { return new Symbol(Terminal.FOLLOWING, yyline+1, yycolumn+1, kwFollowing); }
"following-sibling" { return new Symbol(Terminal.FOLLOWING_SIBLING, yyline+1, yycolumn+1, kwFollowingSibling); }
"for" { return new Symbol(Terminal.FOR, yyline+1, yycolumn+1, kwFor); }
"for-each" { return new Symbol(Terminal.FOR_EACH, yyline+1, yycolumn+1, kwForEach); }
"for-each-group" { return new Symbol(Terminal.FOR_EACH_GROUP, yyline+1, yycolumn+1, kwForEachGroup); }
"function" { return new Symbol(Terminal.FUNCTION, yyline+1, yycolumn+1, kwFunction); }
"ge" { return new Symbol(Terminal.FORTRAN_GE, yyline+1, yycolumn+1, kwGe); }
"gt" { return new Symbol(Terminal.FORTRAN_GT, yyline+1, yycolumn+1, kwGt); }
"idiv" { return new Symbol(Terminal.IDIV, yyline+1, yycolumn+1, kwIdiv); }
"if" { return new Symbol(Terminal.IF, yyline+1, yycolumn+1, kwIf); }
"import" { return new Symbol(Terminal.IMPORT, yyline+1, yycolumn+1, kwImport); }
"import-schema" { return new Symbol(Terminal.IMPORT_SCHEMA, yyline+1, yycolumn+1, kwImportSchema); }
"in" { return new Symbol(Terminal.IN, yyline+1, yycolumn+1, kwIn); }
"include" { return new Symbol(Terminal.INCLUDE, yyline+1, yycolumn+1, kwInclude); }
"instance" { /*yybegin(XPATH_DEFAULT);*/ return new Symbol(Terminal.INSTANCE, yyline+1, yycolumn+1, kwInstance); }
"intersect" { return new Symbol(Terminal.INTERSECT, yyline+1, yycolumn+1, kwIntersect); }
"is" { return new Symbol(Terminal.IS, yyline+1, yycolumn+1, kwIs); }
"isnot" { return new Symbol(Terminal.ISNOT, yyline+1, yycolumn+1, kwIsNot); }
"item" { return new Symbol(Terminal.ITEM, yyline+1, yycolumn+1, kwItem); }
"key" { return new Symbol(Terminal.KEY, yyline+1, yycolumn+1, kwKey); }
"le" { return new Symbol(Terminal.FORTRAN_LE, yyline+1, yycolumn+1, kwLe); }
"lt" { return new Symbol(Terminal.FORTRAN_LT, yyline+1, yycolumn+1, kwLt); }
"match" { return new Symbol(Terminal.MATCH, yyline+1, yycolumn+1, kwMatch); }
"matching-substring" { return new Symbol(Terminal.MATCHING_SUBSTRING, yyline+1, yycolumn+1, kwMatchingSubstring); }
"message" { return new Symbol(Terminal.MESSAGE, yyline+1, yycolumn+1, kwMessage); }
"mod" { return new Symbol(Terminal.MOD, yyline+1, yycolumn+1, kwMod); }
"namespace" { return new Symbol(Terminal.NAMESPACE, yyline+1, yycolumn+1, kwNamespace); }
"namespace-alias" { return new Symbol(Terminal.NAMESPACE_ALIAS, yyline+1, yycolumn+1, kwNamespaceAlias); }
"ne" { return new Symbol(Terminal.FORTRAN_NE, yyline+1, yycolumn+1, kwNe); }
"node" { return new Symbol(Terminal.NODE, yyline+1, yycolumn+1, kwNode); }
"non-matching-substring" { return new Symbol(Terminal.NON_MATCHING_SUBSTRING, yyline+1, yycolumn+1, kwNonMatchingSubstring); }
"number" { return new Symbol(Terminal.NUMBER, yyline+1, yycolumn+1, kwNumber); }
"of" { return new Symbol(Terminal.OF, yyline+1, yycolumn+1, kwOf); }
"or" { return new Symbol(Terminal.OR, yyline+1, yycolumn+1, kwOr); }
"otherwise" { return new Symbol(Terminal.OTHERWISE, yyline+1, yycolumn+1, kwOtherwise); }
"output" { return new Symbol(Terminal.OUTPUT, yyline+1, yycolumn+1, kwOutput); }
"parent" { return new Symbol(Terminal.PARENT, yyline+1, yycolumn+1, kwParent); }
"preceding" { return new Symbol(Terminal.PRECEDING, yyline+1, yycolumn+1, kwPreceding); }
"preceding-sibling" { return new Symbol(Terminal.PRECEDING_SIBLING, yyline+1, yycolumn+1, kwPrecedingSibling); }
"preserve-space" { return new Symbol(Terminal.PRESERVE_SPACE, yyline+1, yycolumn+1, kwPreserveSpace); }
"principal-result-document" { return new Symbol(Terminal.PRINCIPAL_RESULT_DOCUMENT, yyline+1, yycolumn+1, kwPrincipalResultDocument); }
"processing-instruction" { return new Symbol(Terminal.PROCESSING_INSTRUCTION, yyline+1, yycolumn+1, kwProcessingInstruction); }
"result" { return new Symbol(Terminal.RESULT, yyline+1, yycolumn+1, kwResult); }
"result-document" { return new Symbol(Terminal.RESULT_DOCUMENT, yyline+1, yycolumn+1, kwResultDocument); }
"return" { return new Symbol(Terminal.RETURN, yyline+1, yycolumn+1, kwReturn); }
"satisfies" { return new Symbol(Terminal.SATISFIES, yyline+1, yycolumn+1, kwSatisfies); }
"self" { return new Symbol(Terminal.SELF, yyline+1, yycolumn+1, kwSelf); }
"some" { return new Symbol(Terminal.SOME, yyline+1, yycolumn+1, kwSome); }
"sort" { return new Symbol(Terminal.SORT, yyline+1, yycolumn+1, kwSort); }
"sort-key" { return new Symbol(Terminal.SORT_KEY, yyline+1, yycolumn+1, kwSortKey); }
"strip-space" { return new Symbol(Terminal.STRIP_SPACE, yyline+1, yycolumn+1, kwStripSpace); }
"stylesheet" { return new Symbol(Terminal.STYLESHEET, yyline+1, yycolumn+1, kwStylesheet); }
"text" { return new Symbol(Terminal.TEXT, yyline+1, yycolumn+1, kwText); }
"then" { return new Symbol(Terminal.THEN, yyline+1, yycolumn+1, kwThen); }
"to" { return new Symbol(Terminal.TO, yyline+1, yycolumn+1, kwTo); }
"treat" { return new Symbol(Terminal.TREAT, yyline+1, yycolumn+1, kwTreat); }
"type" { return new Symbol(Terminal.TYPE, yyline+1, yycolumn+1, kwType); }
"union" { return new Symbol(Terminal.UNION, yyline+1, yycolumn+1, kwUnion); }
"unordered" { return new Symbol(Terminal.UNORDERED, yyline+1, yycolumn+1, kwUnordered); }
"untyped" { return new Symbol(Terminal.UNTYPED, yyline+1, yycolumn+1, kwUntyped); }
"validate" { return new Symbol(Terminal.VALIDATE, yyline+1, yycolumn+1, kwValidate); }
"value" { return new Symbol(Terminal.VALUE, yyline+1, yycolumn+1, kwValue); }
"value-of" { return new Symbol(Terminal.VALUE_OF, yyline+1, yycolumn+1, kwValueOf); }
"variable" { return new Symbol(Terminal.VARIABLE, yyline+1, yycolumn+1, kwVariable); }
"when" { return new Symbol(Terminal.WHEN, yyline+1, yycolumn+1, kwWhen); }
"xml" { return new Symbol(Terminal.XML, yyline+1, yycolumn+1, kwXml); }

"<" { return new Symbol(Terminal.LT, yyline+1, yycolumn+1, opLt); }
">" { return new Symbol(Terminal.GT, yyline+1, yycolumn+1, opGt); }
"{" { return new Symbol(Terminal.LBRACE, yyline+1, yycolumn+1, opLBrace); }
"}" { return new Symbol(Terminal.RBRACE, yyline+1, yycolumn+1, opRBrace); }
"(" { return new Symbol(Terminal.LPAR, yyline+1, yycolumn+1, opLPar); }
")" { return new Symbol(Terminal.RPAR, yyline+1, yycolumn+1, opRPar); }
"[" { return new Symbol(Terminal.LBRACK, yyline+1, yycolumn+1, opLBrack); }
"]" { return new Symbol(Terminal.RBRACK, yyline+1, yycolumn+1, opRBrack); }
"/" { return new Symbol(Terminal.SLASH, yyline+1, yycolumn+1, opSlash); }
";" { return new Symbol(Terminal.SEMI, yyline+1, yycolumn+1, opSemi); }
":" { return new Symbol(Terminal.COLON, yyline+1, yycolumn+1, opColon); }
"," { return new Symbol(Terminal.COMMA, yyline+1, yycolumn+1, opComma); }
"=" { return new Symbol(Terminal.EQUALS, yyline+1, yycolumn+1, opEquals); }
"$" { return new Symbol(Terminal.DOLLAR, yyline+1, yycolumn+1, opDollar); }
"*" { return new Symbol(Terminal.STAR, yyline+1, yycolumn+1, opStar); }
"|" { return new Symbol(Terminal.VBAR, yyline+1, yycolumn+1, opVBar); }
"?" { return new Symbol(Terminal.QMARK, yyline+1, yycolumn+1, opQmark); }
"@" { return new Symbol(Terminal.AT, yyline+1, yycolumn+1, opAt); }
"." { return new Symbol(Terminal.DOT, yyline+1, yycolumn+1, opDot); }
"+" { return new Symbol(Terminal.PLUS, yyline+1, yycolumn+1, opPlus); }
"-" { return new Symbol(Terminal.MINUS, yyline+1, yycolumn+1, opMinus); }
"!" { return new Symbol(Terminal.PLING, yyline+1, yycolumn+1, opPling); }

"!=" { return new Symbol(Terminal.NOT_EQUALS, yyline+1, yycolumn+1, opNotEquals); }
"<=" { return new Symbol(Terminal.LT_EQUALS, yyline+1, yycolumn+1, opLtEquals); }
">=" { return new Symbol(Terminal.GT_EQUALS, yyline+1, yycolumn+1, opGtEquals); }
"//" { return new Symbol(Terminal.SLASH_SLASH, yyline+1, yycolumn+1, opSlashSlash); }
"::" { return new Symbol(Terminal.COLON_COLON, yyline+1, yycolumn+1, opColonColon); }
":=" { return new Symbol(Terminal.COLON_EQUALS, yyline+1, yycolumn+1, opColonEquals); }
".." { return new Symbol(Terminal.DOT_DOT, yyline+1, yycolumn+1, opDotDot); }

{ExprComment} { /* Ignore comments */ }
{MultiLineComment} { return new Symbol(Terminal.Comment, yyline+1, yycolumn+1, yytext().substring(4,yytext().length()-3)); }
{SingleLineComment} { /* ignore single line comment. */ }
{DecimalLiteral} { return new Symbol(Terminal.DecimalLiteral, yyline+1, yycolumn+1, yytext()); }
{DoubleLiteral} { return new Symbol(Terminal.DoubleLiteral, yyline+1, yycolumn+1, yytext()); }
{IntegerLiteral} { return new Symbol(Terminal.IntegerLiteral, yyline+1, yycolumn+1, yytext()); }
{NCName} { return new Symbol(Terminal.PartialNCName, yyline+1, yycolumn+1, yytext()); }
{StringLiteral} { return new Symbol(Terminal.StringLiteral, yyline+1, yycolumn+1, decode(yytext())); }

[ \t\r\n\f]* { /* ignore white space. */ }

. { return new Symbol(Terminal.IllegalCharacter, yyline+1, yycolumn+1, yytext()); }
